<?php

use \chatbro\Chatbrochats;
use \chatbro\traits\LibraryLoader;
use \chatbro\traits\StoreLoader;
use chatbro\Log;

class ControllerExtensionModuleChatbro extends Controller
{
    use StoreLoader;
    use LibraryLoader;

    private $debug_log;
    const DEBUG_LOG_FILENAME = 'chatbro.%s.log';

    private $store_id = 0;

    public function __construct($registry)
    {
        parent::__construct($registry);

        $this->store_id = isset($this->request->get['store_id']) ? (int) $this->request->get['store_id'] : 0;
        $this->debug_log = new Log(sprintf(self::DEBUG_LOG_FILENAME, $this->store_id));

        $this->loadStore($this->store_id);
        $this->loadLibrary($this->store_id);
    }

    public function index(): void
    {
        $this->load->model('extension/module/chatbro');
        $this->model_extension_module_chatbro->createTables();

        $this->load->language('extension/module/chatbro');
        $this->document->setTitle($this->language->get('heading_title'));

        $this->document->addStyle('view/stylesheet/module/chatbro.css');
        $this->document->addStyle('view/stylesheet/module/chatbro-bootstrap.css');

        $this->document->addScript('view/javascript/module/chatbro.js');
        $this->document->addScript('view/javascript/module/common.js');

        $this->initChatbro();

        $data['breadcrumbs'] = [];
        $data['breadcrumbs'][] = [
            'text' => $this->language->get('text_home'),
            'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'])
        ];
        $data['breadcrumbs'][] = [
            'text' => $this->language->get('text_extension'),
            'href' => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module')
        ];
        $data['breadcrumbs'][] = [
            'text' => $this->language->get('heading_title'),
            'href' => $this->url->link('extension/module/chatbro', 'user_token=' . $this->session->data['user_token'])
        ];

        $data['back'] = $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module');
        $data['text_panel_heading'] = $this->language->get('text_edit');


        $data['header'] = $this->load->controller('common/header');
        $data['column_left'] = $this->load->controller('common/column_left');
        $data['footer'] = $this->load->controller('common/footer');

        $data['render_admin_block'] = $this->chatbroapp->admin();

        $this->response->setOutput($this->load->view('extension/module/chatbro', $data));
    }

    protected function initChatbro()
    {
        $this->chatbroapp->init();
    }

    public function get_chats(): void
    {
        $this->initChatbro();
        $json = $this->chatbroapp->getChats();

        $this->response->addHeader('Content-Type: text/html; charset=utf-8');
        $this->response->setOutput($json);
    }

    public function delete_chat(): void
    {
        $this->initChatbro();
        $json = $this->chatbroapp->deleteChat();

        $this->response->addHeader('Content-Type: application/json');
        $this->response->setOutput(json_encode($json));
    }

    public function update_chat(): void
    {
        $this->initChatbro();
        $json = $this->chatbroapp->updateChat();

        $this->response->addHeader('Content-Type: application/json');
        $this->response->setOutput(json_encode($json));
    }

    public function save_settings(): void
    {

        $this->initChatbro();
        $json = $this->chatbroapp->saveSettings();

        $this->response->addHeader('Content-Type: application/json');
        $this->response->setOutput(json_encode($json));
    }

    public function create_chat(): void
    {
        $this->initChatbro();
        $json = $this->chatbroapp->createChat();

        $this->response->addHeader('Content-Type: application/json');
        $this->response->setOutput(json_encode($json));
    }

    public function view_column_left(string $route, array &$data): void
    {
        $chatbro_menu = [
            'id' => 'menu-chatbro',
            'icon' => 'fa fa-cog',
            'name' => 'Chatbro Extension',
            'href' => $this->url->link('extension/module/chatbro', 'user_token=' . $this->session->data['user_token'], true),
            'children' => []
        ];

        array_unshift($data['menus'], $chatbro_menu);
    }

    public function install(): void
    {
        $this->load->model('extension/module/chatbro');
        $this->model_extension_module_chatbro->createTables();
        $this->model_extension_module_chatbro->createEvents();
    }

    public function uninstall(): void
    {
        $this->load->model('extension/module/chatbro');
        $this->model_extension_module_chatbro->dropTables();
        $this->model_extension_module_chatbro->deleteEvents();
    }
}
